| as_variable_metadata | R Documentation |
Normalizes the accepted metadata inputs into a single tidy table with one row
per dataset variable. A metacore object is unpacked
into its dataset, variable, and derivation components; a data.frame is checked
for the required dataset and variable columns and completed with any
missing optional columns.
as_variable_metadata(metadata)
metadata |
Either a |
A tibble with columns dataset, variable,
label, type, origin, derivation, and is_derived.
# The example ADaM metadata shipped in r4subdata.
meta <- as_variable_metadata(r4subdata::adam_metadata)
head(meta)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.